==> qtjambi-help-6.6.3-sources.jar: io/qt/help/QHelpContentWidget.java <==
package io.qt.help;

import io.qt.*;


/**
 * <p>Tree view for displaying help content model items</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhelpcontentwidget.html">QHelpContentWidget</a></code></p>
 */
public final class QHelpContentWidget extends io.qt.widgets.QTreeView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentWidget.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentwidget.html#linkActivated">QHelpContentWidget::<wbr/>linkActivated(QUrl)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.core.@NonNull QUrl> linkActivated = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentwidget.html#indexOf">QHelpContentWidget::<wbr/>indexOf(QUrl)</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QModelIndex indexOf(io.qt.core.@NonNull QUrl link){
        return indexOf_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(link));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex indexOf_native_cref_QUrl(long __this__nativeId, long link);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QHelpContentWidget(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #indexOf(io.qt.core.QUrl)}.</p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QModelIndex indexOf(java.lang.@NonNull String link) {
        return indexOf(new io.qt.core.QUrl(link));
    }
}

==> qtjambi-help-6.7.1-sources.jar: io/qt/help/QHelpContentWidget.java <==
package io.qt.help;

import io.qt.*;


/**
 * <p>Tree view for displaying help content model items</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qhelpcontentwidget.html">QHelpContentWidget</a></code></p>
 */
public final class QHelpContentWidget extends io.qt.widgets.QTreeView
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpContentWidget.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentwidget.html#linkActivated">QHelpContentWidget::<wbr/>linkActivated(QUrl)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.core.@NonNull QUrl> linkActivated = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qhelpcontentwidget.html#indexOf">QHelpContentWidget::<wbr/>indexOf(QUrl)</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QModelIndex indexOf(io.qt.core.@NonNull QUrl link){
        return indexOf_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(link));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex indexOf_native_cref_QUrl(long __this__nativeId, long link);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    private QHelpContentWidget(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #indexOf(io.qt.core.QUrl)}.</p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QModelIndex indexOf(java.lang.@NonNull String link) {
        return indexOf(new io.qt.core.QUrl(link));
    }
}
